use crate::ha_client::EntityId;
use deckster_mode::shared::state::KeyStyleByStateMap;
use serde::Deserialize;
use url::Url;

#[derive(Debug, Clone, Deserialize)]
pub struct GlobalConfig {
    pub base_url: Url,
    pub token: Box<str>,
}

#[derive(Debug, Clone, Deserialize)]
pub struct KeyConfig {
    pub disconnected_state: Option<Box<str>>,
    #[serde(flatten)]
    pub mode: KeyMode,
    #[serde(default)]
    pub style: KeyStyleByStateMap<Box<str>>,
}

#[derive(Debug, Clone, Deserialize)]
#[serde(tag = "mode", rename_all = "kebab-case")]
pub enum KeyMode {
    Toggle { entity_id: EntityId },
    Button { state_entity_id: EntityId, button_entity_id: EntityId },
}

impl KeyMode {
    #[inline]
    pub fn state_entity_id(&self) -> &EntityId {
        match &self {
            KeyMode::Toggle { entity_id, .. } => entity_id,
            KeyMode::Button { state_entity_id, .. } => state_entity_id,
        }
    }
}
